@@ -1,12 +1,9 @@
 #!/bin/false
-# ABSTRACT: Object methods to create a DHCP packet
-# PODNAME: Net::DHCP
+package Net::DHCP;
 use strict;
 use warnings;
 
-package Net::DHCP;
-$Net::DHCP::VERSION = '0.7_010'; # TRIAL
-$Net::DHCP::VERSION = '0.7010';
+our $VERSION = 0.681;
 
 1;
 
@@ -14,21 +11,15 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
-Net::DHCP - Object methods to create a DHCP packet
-
-=head1 VERSION
-
-version 0.7_010
+Net::DHCP - Object methods to create a DHCP packet.
 
 =head1 SYNOPSIS
 
    use Net::DHCP::Packet;
 
-   my $p = Net::DHCP::Packet->new(
+   my $p = new Net::DHCP::Packet->new(
         'Chaddr' => '000BCDEF',
         'Xid' => 0x9F0FD,
         'Ciaddr' => '0.0.0.0',
@@ -39,20 +30,25 @@ version 0.7_010
 
 Represents a DHCP packet as specified in RFC 1533, RFC 2132.
 
+=head1 AUTHOR
+
+Dean Hamstead E<lt>djzort@cpan.orgE<gt>
+
+=head1 SOURCE REPO
+
+See L<https://github.com/djzort/Net-DHCP>
+
+=head1 BUGS
+
+See L<https://rt.cpan.org/Dist/Display.html?Queue=Net-DHCP>
+
+=head1 COPYRIGHT
+
+This is free software. It can be distributed and/or modified under the same terms as
+Perl itself.
+
 =head1 SEE ALSO
 
 L<Net::DHCP::Options>, L<Net::DHCP::Constants>.
 
-=head1 AUTHOR
-
-Dean Hamstead <dean@fragfest.com.au>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2022 by Dean Hamstead.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
 =cut
